@@ -2,6 +2,34 @@ use crate::AsClasses;
 use yew::prelude::*;
 use yew::virtual_dom::VNode;
 
+pub enum State {
+    None,
+    Danger,
+    Default,
+    Info,
+    Success,
+    Warning,
+    Disabled,
+}
+
+impl State {
+    fn var(name: &str, weight: usize) -> String {
+        format!("--pf-global--{}-color--{}", name, weight)
+    }
+
+    pub fn as_var(&self, weight: usize) -> Option<String> {
+        match self {
+            Self::None => None,
+            Self::Danger => Some(Self::var("danger", weight)),
+            Self::Default => Some(Self::var("default", weight)),
+            Self::Info => Some(Self::var("info", weight)),
+            Self::Success => Some(Self::var("success", weight)),
+            Self::Warning => Some(Self::var("warning", weight)),
+            Self::Disabled => Some(Self::var("disabled", weight)),
+        }
+    }
+}
+
 macro_rules! icons {
     ($($n:ident => $e:expr),* $(,)?) => {
         #[derive(Copy, Clone, Debug, PartialEq, Eq)]
@@ -42,8 +70,6 @@ icons! {
 
     InfoCircle => fas("fa-info-circle"),
 
-    OutlinedQuestionCircle => far("fa-question-circle"),
-
     Pause => fas("fa-pause"),
     Play => fas("fa-play"),
     PlusCircleIcon => fas("fa-plus-circle"),
@@ -62,6 +88,23 @@ impl Icon {
         self.with_classes(Classes::new())
     }
 
+    pub fn with_state(&self, state: State) -> Html {
+        self.with_state_weight(state, 200)
+    }
+
+    pub fn with_state_weight(&self, state: State, weight: usize) -> Html {
+        let style = state
+            .as_var(weight)
+            .map(|v| format!("color: var({});", v))
+            .unwrap_or_default();
+
+        html! {
+            <span style=style>
+                { self.as_html() }
+            </span>
+        }
+    }
+
     pub fn with_classes(&self, classes: Classes) -> Html {
         let icon_classes = self.as_classes();
 
@@ -71,13 +114,6 @@ impl Icon {
     }
 }
 
-fn far(name: &str) -> Classes {
-    let mut classes = Classes::new();
-    classes.push("far");
-    classes.push(name);
-    classes
-}
-
 fn fas(name: &str) -> Classes {
     let mut classes = Classes::new();
     classes.push("fas");
