@@ -1,5 +1,7 @@
 #[cfg(feature = "router")]
 mod router;
+mod simple;
 
 #[cfg(feature = "router")]
 pub use router::*;
+pub use simple::*;
