@@ -1,6 +1,7 @@
 mod action;
 mod breakpoint;
 mod classes;
+mod global_close;
 mod orientation;
 mod position;
 mod size;
@@ -9,6 +10,7 @@ mod space;
 pub use action::*;
 pub use breakpoint::*;
 pub use classes::*;
+pub use global_close::*;
 pub use orientation::*;
 pub use position::*;
 pub use size::*;
